OwLite
=====================

**WARNING:** This project is not functional and is a placeholder from SqueezeBits. 
To install, please execute the following:

```bash
$ pip install owlite --extra-index-url https://pypi.squeezebits.com/
```

Please visit us at https://www.squeezebits.com or github.com/SqueezeBits/owlite for further information.